==> nextcloud-27.1.4.tgz: nextcloud/apps/systemtags/l10n/hr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sustav je dodao oznaku sustava %1$s",
    "Added system tag {systemtag}" : "Dodana oznaka sustava {systemtag}",
    "Added system tag %1$s" : "Dodana oznaka sustava %1$s",
    "%1$s added system tag %2$s" : "%1$s je dodao oznaku sustava %2$s",
    "{actor} added system tag {systemtag}" : "{actor} je dodao oznaku sustava {systemtag}",
    "System tag %1$s removed by the system" : "Sustav je uklonio oznaku sustava %1$s",
    "Removed system tag {systemtag}" : "Uklonjena oznaka sustava {systemtag}",
    "Removed system tag %1$s" : "Uklonjena oznaka sustava %1$s",
    "%1$s removed system tag %2$s" : "%1$s je uklonio oznaku sustava %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} je uklonio oznaku sustava {systemtag}",
    "You created system tag %1$s" : "Stvorili ste oznaku sustava %1$s",
    "You created system tag {systemtag}" : "Stvorili ste oznaku sustava {systemtag}",
    "%1$s created system tag %2$s" : "%1$s je stvorio oznaku sustava %2$s",
    "{actor} created system tag {systemtag}" : "{actor} je stvorio oznaku sustava {systemtag}",
    "You deleted system tag %1$s" : "Izbrisali ste oznaku sustava %1$s",
    "You deleted system tag {systemtag}" : "Izbrisali ste oznaku sustava {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s je izbrisao oznaku sustava %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} je izbrisao oznaku sustava {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ažurirali ste oznaku sustava %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ažurirali ste oznaku sustava {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s je ažurirao oznaku sustava %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} je ažurirao oznaku sustava {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Sustav je dodao u %1$s oznaku sustava %2$s",
    "System tag {systemtag} was added to {file} by the system" : "Sustav je dodao u {file} oznaku sustava {systemtag}",
    "You added system tag %2$s to %1$s" : "Dodali ste oznaku sustava %2$s u %1$s",
    "You added system tag {systemtag} to {file}" : "Dodali ste oznaku sustava {systemtag} u {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s je dodao oznaku sustava %3$s u %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} je dodao oznaku sustava {systemtag} u {file}",
    "System tag %2$s was removed from %1$s by the system" : "Sustav je uklonio iz %1$s oznaku sustava %2$s",
    "System tag {systemtag} was removed from {file} by the system" : "Sustav je uklonio iz {file} oznaku sustava {systemtag}",
    "You removed system tag %2$s from %1$s" : "Uklonili ste oznaku sustava %2$s iz %1$s",
    "You removed system tag {systemtag} from {file}" : "Uklonili ste oznaku sustava {systemtag} iz {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s je uklonio oznaku sustava %3$s iz %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} je uklonio oznaku sustava {systemtag} iz {file}",
    "%s (restricted)" : "%s (ograničeno)",
    "%s (invisible)" : "%s (nevidljivo)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Oznake sustava</strong> za datoteku su izmijenjene",
    "Tags" : "Oznake",
    "Collaborative tags" : "Oznake za suradnju",
    "Collaborative tagging functionality which shares tags among users." : "Funkcija kolaborativnog označavanja dijeli oznake među korisnicima.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcija kolaborativnog označavanja dijeli oznake među korisnicima. Izvrsna ideja za timove.\n\t(Ako ste davatelj usluga s instalacijom za više stanara, deaktivirajte ovu aplikaciju jer se dijele oznake.)",
    "Create" : "Stvori",
    "Update" : "Ažuriraj",
    "Delete" : "Izbriši",
    "Reset" : "Resetiraj",
    "Loading …" : "Učitavanje…",
    "Public" : "Javna",
    "Restricted" : "Ograničena",
    "Invisible" : "Nevidljiva",
    "Failed to load tags" : "Učitavanje oznaka nije uspjelo",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Oznake za suradnju dostupne su svim korisnicima. Ograničene oznake vidljive su korisnicima, ali ih ne mogu dodijeliti. Nevidljive oznake služe za internu uporabu jer ih korisnici ne mogu vidjeti niti dodijeliti.",
    "No tags found" : "Nema pronađenih oznaka",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "Tag name is empty" : "Nema naziva oznake",
    "Select tag …" : "Odaberite oznaku…",
    "Tagged files" : "Označene datoteke",
    "Select tags to filter by" : "Odaberite oznake za filtriranje",
    "Please select tags to filter by" : "Odaberite oznake za filtriranje prema",
    "No files found for the selected tags" : "Nije pronađena nijedna datoteka za odabrane oznake",
    "Create a new tag" : "Stvori novu oznaku"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-28.0.3.tgz: nextcloud/apps/systemtags/l10n/hr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sustav je dodao oznaku sustava %1$s",
    "Added system tag {systemtag}" : "Dodana oznaka sustava {systemtag}",
    "Added system tag %1$s" : "Dodana oznaka sustava %1$s",
    "%1$s added system tag %2$s" : "%1$s je dodao oznaku sustava %2$s",
    "{actor} added system tag {systemtag}" : "{actor} je dodao oznaku sustava {systemtag}",
    "System tag %1$s removed by the system" : "Sustav je uklonio oznaku sustava %1$s",
    "Removed system tag {systemtag}" : "Uklonjena oznaka sustava {systemtag}",
    "Removed system tag %1$s" : "Uklonjena oznaka sustava %1$s",
    "%1$s removed system tag %2$s" : "%1$s je uklonio oznaku sustava %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} je uklonio oznaku sustava {systemtag}",
    "You created system tag %1$s" : "Stvorili ste oznaku sustava %1$s",
    "You created system tag {systemtag}" : "Stvorili ste oznaku sustava {systemtag}",
    "%1$s created system tag %2$s" : "%1$s je stvorio oznaku sustava %2$s",
    "{actor} created system tag {systemtag}" : "{actor} je stvorio oznaku sustava {systemtag}",
    "You deleted system tag %1$s" : "Izbrisali ste oznaku sustava %1$s",
    "You deleted system tag {systemtag}" : "Izbrisali ste oznaku sustava {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s je izbrisao oznaku sustava %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} je izbrisao oznaku sustava {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ažurirali ste oznaku sustava %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ažurirali ste oznaku sustava {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s je ažurirao oznaku sustava %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} je ažurirao oznaku sustava {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Sustav je dodao u %1$s oznaku sustava %2$s",
    "System tag {systemtag} was added to {file} by the system" : "Sustav je dodao u {file} oznaku sustava {systemtag}",
    "You added system tag %2$s to %1$s" : "Dodali ste oznaku sustava %2$s u %1$s",
    "You added system tag {systemtag} to {file}" : "Dodali ste oznaku sustava {systemtag} u {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s je dodao oznaku sustava %3$s u %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} je dodao oznaku sustava {systemtag} u {file}",
    "System tag %2$s was removed from %1$s by the system" : "Sustav je uklonio iz %1$s oznaku sustava %2$s",
    "System tag {systemtag} was removed from {file} by the system" : "Sustav je uklonio iz {file} oznaku sustava {systemtag}",
    "You removed system tag %2$s from %1$s" : "Uklonili ste oznaku sustava %2$s iz %1$s",
    "You removed system tag {systemtag} from {file}" : "Uklonili ste oznaku sustava {systemtag} iz {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s je uklonio oznaku sustava %3$s iz %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} je uklonio oznaku sustava {systemtag} iz {file}",
    "%s (restricted)" : "%s (ograničeno)",
    "%s (invisible)" : "%s (nevidljivo)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Oznake sustava</strong> za datoteku su izmijenjene",
    "Tags" : "Oznake",
    "Collaborative tags" : "Oznake za suradnju",
    "Create" : "Stvori",
    "Update" : "Ažuriraj",
    "Delete" : "Izbriši",
    "Reset" : "Resetiraj",
    "Loading …" : "Učitavanje…",
    "Public" : "Javna",
    "Restricted" : "Ograničena",
    "Invisible" : "Nevidljiva",
    "Failed to load tags" : "Učitavanje oznaka nije uspjelo",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Oznake za suradnju dostupne su svim korisnicima. Ograničene oznake vidljive su korisnicima, ali ih ne mogu dodijeliti. Nevidljive oznake služe za internu uporabu jer ih korisnici ne mogu vidjeti niti dodijeliti.",
    "No tags found" : "Nema pronađenih oznaka",
    "Tag name is empty" : "Nema naziva oznake",
    "Select tag …" : "Odaberite oznaku…",
    "Collaborative tagging functionality which shares tags among users." : "Funkcija kolaborativnog označavanja dijeli oznake među korisnicima.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcija kolaborativnog označavanja dijeli oznake među korisnicima. Izvrsna ideja za timove.\n\t(Ako ste davatelj usluga s instalacijom za više stanara, deaktivirajte ovu aplikaciju jer se dijele oznake.)",
    "Tagged files" : "Označene datoteke",
    "Select tags to filter by" : "Odaberite oznake za filtriranje",
    "Please select tags to filter by" : "Odaberite oznake za filtriranje prema",
    "No files found for the selected tags" : "Nije pronađena nijedna datoteka za odabrane oznake",
    "Create a new tag" : "Stvori novu oznaku",
    "Name" : "Naziv",
    "No files in here" : "Nema datoteka",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
